@@ -35,7 +35,8 @@
     (if not contributing author is listed, this file has been contributed
     by the core developer)
 
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Philippe Seil (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
@@ -108,8 +109,11 @@
   bool AssociativePointerArray<T>::sameLength(int _len)
   {
     for(int i = 0; i < numElem_; i++)
+    {
+        
         if(content_[i]->size() != _len)
             return false;
+    }
     return true;
   }
 
@@ -145,7 +149,7 @@
   }
 
   template<typename T>
-  T* AssociativePointerArray<T>::getBasePointerByIndex(int i)
+  T* AssociativePointerArray<T>::getBasePointerByIndex(int i) const
   {
     if(i >= size() || i < 0) return 0;
     else return content_[i];
@@ -182,19 +186,7 @@
   }
 
   template<typename T>
-  void AssociativePointerArray<T>::grow(int to)
-   {
-      int by;
-      for(int i = 0; i < maxElem_; i++)
-      {
-          by = to - getBasePointerByIndex(i)->size();
-          if(by > 0)
-            getBasePointerByIndex(i)->addUninitialized(by);
-      }
-  }
-
-  template<typename T>
-  int AssociativePointerArray<T>::size()
+  int AssociativePointerArray<T>::size() const
   {
     return numElem_;
   }
@@ -232,6 +224,28 @@
         content_[i]->addZero();
   }
 
+  /* ----------------------------------------------------------------------
+   delete all elements in containers
+  ------------------------------------------------------------------------- */
+
+  template<typename T>
+  void AssociativePointerArray<T>::deleteAllElements()
+  {
+      for(int i=0;i<numElem_;i++)
+        content_[i]->clearContainer();
+  }
+
+  /* ----------------------------------------------------------------------
+   delete all restart elements in containers
+  ------------------------------------------------------------------------- */
+
+  template<typename T>
+  void AssociativePointerArray<T>::deleteRestart(bool scale,bool translate,bool rotate)
+  {
+      for(int i=0;i<numElem_;i++)
+        content_[i]->delRestart(scale,translate,rotate);
+  }
+
   /* ----------------------------------------------------------------------
    delete element n
   ------------------------------------------------------------------------- */
@@ -287,6 +301,45 @@
         content_[i]->clearReverse(scale,translate,rotate);
   }
 
+  /* ----------------------------------------------------------------------
+   statistic functions
+  ------------------------------------------------------------------------- */
+
+  template<typename T>
+  bool AssociativePointerArray<T>::calcStatistics()
+  {
+      int ret = true;
+      const int  maxLevel = maxStatLevel();
+
+      for(int j=1;j<=maxLevel;j++)
+      {
+          for(int i=0;i<numElem_;i++)
+              if( (content_[i]->getStatLevel() == j) && (content_[i]->isStatisticsContainer() && !(content_[i]->isScalingContainer())))
+                  ret = ret && content_[i]->calcStatistics();
+
+          for(int i=0;i<numElem_;i++)
+              if( (content_[i]->getStatLevel() == j) && (content_[i]->isStatisticsContainer() && content_[i]->isScalingContainer()))
+                  ret = ret && content_[i]->updateScalingContainer();
+          for(int i=0;i<numElem_;i++)
+              if( (content_[i]->getStatLevel() == j) && (content_[i]->isStatisticsContainer() && (!content_[i]->isScalingContainer())))
+                  ret = ret && content_[i]->normalizeStatistics();
+      }
+
+      // return false if any returns false
+      return ret;
+  }
+
+  template<typename T>
+  int  AssociativePointerArray<T>::maxStatLevel() const
+  {
+      int maxLevel = 0;
+
+      for(int i=0;i<numElem_;i++)
+          maxLevel = std::max(maxLevel, content_[i]->getStatLevel());
+
+      return maxLevel;
+  }
+
   /* ----------------------------------------------------------------------
    id 2 index
   ------------------------------------------------------------------------- */
@@ -388,7 +441,7 @@
   ------------------------------------------------------------------------- */
 
   template<typename T>
-  int AssociativePointerArray<T>::bufSize(int operation,bool scale,bool translate,bool rotate)
+  int AssociativePointerArray<T>::bufSize(int operation,bool scale,bool translate,bool rotate) const
   {
     int buf_size = 0;
     for(int i=0;i<numElem_;i++)
