@@ -40,8 +40,8 @@
 ------------------------------------------------------------------------- */
 
 #include "sys/stat.h"
-#include "string.h"
-#include "stdlib.h"
+#include <string.h>
+#include <stdlib.h>
 #include "atom.h"
 #include "comm.h"
 #include "update.h"
@@ -49,7 +49,7 @@
 #include "error.h"
 #include "memory.h"
 #include "modify.h"
-#include "math.h"
+#include <math.h>
 #include "vector_liggghts.h"
 #include "fix_property_atom.h"
 #include "fix_property_global.h"
