@@ -49,7 +49,7 @@ COHESION_MODEL(COHESION_SJKR2,sjkr2,2)
 
 #include "pointers.h"
 #include "contact_models.h"
-#include "math.h"
+#include <math.h>
 
 namespace LIGGGHTS {
 namespace ContactModels {
@@ -61,8 +61,6 @@ namespace ContactModels {
   public:
     static const int MASK = CM_CONNECT_TO_PROPERTIES | CM_SURFACES_INTERSECT;
 
-    int bond_history_offset() {return -1;}
-
     CohesionModel(LAMMPS * lmp, IContactHistorySetup*,class ContactModelBase *) :
         Pointers(lmp), cohEnergyDens(NULL)
     {
