@@ -47,8 +47,8 @@
    Contributing author: Wan Liang (Chinese Academy of Sciences)
 ------------------------------------------------------------------------- */
 
-#include "string.h"
-#include "stdlib.h"
+#include <string.h>
+#include <stdlib.h>
 #include "compute_cna_atom.h"
 #include "atom.h"
 #include "update.h"
@@ -61,7 +61,7 @@
 #include "comm.h"
 #include "memory.h"
 #include "error.h"
-#include "math.h"
+#include <math.h>
 
 using namespace LAMMPS_NS;
 
