@@ -49,7 +49,7 @@
     the GNU General Public License.
 ------------------------------------------------------------------------- */
 
-#include "mpi.h"
+#include <mpi.h>
 #include "compute_erotate_sphere.h"
 #include "atom.h"
 #include "atom_vec.h"
