@@ -46,8 +46,8 @@
 #ifndef LMP_DUMP_H
 #define LMP_DUMP_H
 
-#include "mpi.h"
-#include "stdio.h"
+#include <mpi.h>
+#include <stdio.h>
 #include "pointers.h"
 
 namespace LAMMPS_NS {
