@@ -39,7 +39,7 @@
     Copyright 2009-2012 JKU Linz
 ------------------------------------------------------------------------- */
 
-#include "string.h"
+#include <string.h>
 #include "dump_euler_vtk.h"
 #include "fix_ave_euler.h"
 #include "domain.h"
