@@ -40,9 +40,9 @@
 
 #ifdef LAMMPS_VTK
 
-#include "math.h"
-#include "stdlib.h"
-#include "string.h"
+#include <math.h>
+#include <stdlib.h>
+#include <string.h>
 #include "dump_local_gran_vtk.h"
 #include "atom.h"
 #include "force.h"
@@ -54,7 +54,7 @@
 #include "update.h"
 #include "modify.h"
 #include "compute.h"
-#include "compute_pair_gran_local_bond.h"
+#include "compute_pair_gran_local.h"
 #include "fix.h"
 #include "memory.h"
 #include "error.h"
@@ -87,7 +87,7 @@ using namespace LAMMPS_NS;
 
 enum{INT,DOUBLE,STRING};       // same as in DumpCFG
 enum{VTK,VTP,VTU,PVTP,PVTU};   // file formats
-enum{X1,X2,V1,V2,ID1,ID2,F,FN,FT,TORQUE,AREA,DELTA,HEAT}; // dumps positions, force, normal and tangential forces, torque
+enum{X1,X2,V1,V2,ID1,ID2,F,FN,FT,TORQUE,TORQUEN,TORQUET,AREA,DELTA,HEAT}; // dumps positions, force, normal and tangential forces, torque, normal and tangential torque
 
 #define INVOKED_VECTOR 2
 #define INVOKED_ARRAY 4
@@ -112,7 +112,7 @@ DumpLocalGranVTK::DumpLocalGranVTK(LAMMPS *lmp, int narg, char **arg) :
   if(!comp || !dynamic_cast<ComputePairGranLocal*>(comp))
     error->all(FLERR,"dump local/gran/vtk requires a valid ID of a compute pair/gran/local to be provided");
 
-  cpgl_ = static_cast<ComputePairGranLocalBond*>(comp);
+  cpgl_ = static_cast<ComputePairGranLocal*>(comp);
 
   // error if compute does not write pos
   if(cpgl_->offset_x1() < 0 || cpgl_->offset_x2() < 0)
@@ -232,7 +232,6 @@ void DumpLocalGranVTK::header_vtk(bigint)
 int DumpLocalGranVTK::count()
 {
   
-  int nmine;
   n_calls_ = 0;
 
   //TODO generalize
@@ -805,6 +804,22 @@ void DumpLocalGranVTK::define_properties()
       vector_set.insert(TORQUE);
   }
 
+  if(cpgl_->offset_torquen() > 0)
+  {
+      pack_choice[TORQUEN] = &DumpLocalGranVTK::pack_torquen;
+      vtype[TORQUEN] = DOUBLE;
+      name[TORQUEN] = "torque_normal";
+      vector_set.insert(TORQUEN);
+  }
+
+  if(cpgl_->offset_torquet() > 0)
+  {
+      pack_choice[TORQUET] = &DumpLocalGranVTK::pack_torquet;
+      vtype[TORQUET] = DOUBLE;
+      name[TORQUET] = "torque_tangential";
+      vector_set.insert(TORQUET);
+  }
+
   if(cpgl_->offset_area() > 0)
   {
       
@@ -868,12 +883,12 @@ int DumpLocalGranVTK::modify_param(int narg, char **arg)
   }
 
   if (strcmp(arg[0],"element") == 0) {
-    error->all(FLERR,"Dump local/bond/gran does not support dump_modify 'element' ");
+    error->all(FLERR,"Dump local/gran/vtk does not support dump_modify 'element' ");
     return 0;
   }
 
   if (strcmp(arg[0],"thresh") == 0) {
-    error->all(FLERR,"Dump local/bond/gran does not support dump_modify 'thresh' ");
+    error->all(FLERR,"Dump local/gran/vtk does not support dump_modify 'thresh' ");
   }
 
   return 0;
@@ -996,6 +1011,26 @@ void DumpLocalGranVTK::pack_torque(int n)
   }
 }
 
+void DumpLocalGranVTK::pack_torquen(int n)
+{
+  int offset = cpgl_->offset_torquen();
+
+  for (int i = 0; i < nchoose; i++) {
+    vectorCopy3D(&cpgl_->get_data()[i][offset],&buf[n]);
+    n += size_one;
+  }
+}
+
+void DumpLocalGranVTK::pack_torquet(int n)
+{
+  int offset = cpgl_->offset_torquet();
+
+  for (int i = 0; i < nchoose; i++) {
+    vectorCopy3D(&cpgl_->get_data()[i][offset],&buf[n]);
+    n += size_one;
+  }
+}
+
 void DumpLocalGranVTK::pack_area(int n)
 {
   int offset = cpgl_->offset_area();
