@@ -47,8 +47,8 @@
    Contributing author: Pieter in 't Veld (SNL)
 ------------------------------------------------------------------------- */
 
-#include "stdlib.h"
-#include "string.h"
+#include <stdlib.h>
+#include <string.h>
 #include "unistd.h"
 #include "fix_ave_time.h"
 #include "update.h"
