@@ -62,9 +62,11 @@ enum
 };
 
 class FixPropertyGlobal : public Fix {
- friend class Modify;
- friend class MechParamGran;
  friend class CfdDatacouplingFile;
+ friend class FixSph;
+ friend class PairSph;
+ friend class Properties;
+ friend class FixTempFromFile;
 
  public:
   FixPropertyGlobal(class LAMMPS *, int, char **);
@@ -97,6 +99,8 @@ class FixPropertyGlobal : public Fix {
 
   void write();
 
+ private:
+
   char *variablename;        // name of the variable (used for identification by other fixes)
   int data_style;            // 0 if a scalar is registered, 1 if vector, 2 if 2d array (matrix)
   int nvalues;
