@@ -46,7 +46,7 @@
 #ifndef LMP_GROUP_H
 #define LMP_GROUP_H
 
-#include "stdio.h"
+#include <stdio.h>
 #include "pointers.h"
 
 namespace LAMMPS_NS {
