@@ -48,7 +48,7 @@ NORMAL_MODEL(HERTZ_STIFFNESS,hertz/stiffness,4)
 #define NORMAL_MODEL_HERTZ_STIFFNESS_H_
 #include "contact_models.h"
 #include "global_properties.h"
-#include "math.h"
+#include <math.h>
 
 namespace LIGGGHTS {
 namespace ContactModels
@@ -111,7 +111,7 @@ namespace ContactModels
       double reff = sidata.is_wall ? sidata.radi : (sidata.radi*sidata.radj/(sidata.radi+sidata.radj));
 #ifdef SUPERQUADRIC_ACTIVE_FLAG
       if(sidata.is_non_spherical)
-        reff = MathExtraLiggghtsSuperquadric::get_effective_radius(sidata);
+        reff = MathExtraLiggghtsNonspherical::get_effective_radius(sidata);
 #endif
 
       const double polyhertz = sqrt(reff*sidata.deltan);
@@ -151,12 +151,12 @@ namespace ContactModels
       sidata.gamman = gamman;
       sidata.gammat = gammat;
 
-      #ifdef SUPERQUADRIC_ACTIVE_FLAG
+      #ifdef NONSPHERICAL_ACTIVE_FLAG
           double torque_i[3];
           double Fn_i[3] = { Fn * sidata.en[0], Fn * sidata.en[1], Fn * sidata.en[2]};
           if(sidata.is_non_spherical) {
             double xci[3];
-            vectorSubtract3D(sidata.contact_point, sidata.pos_i, xci);
+            vectorSubtract3D(sidata.contact_point, atom->x[sidata.i], xci);
             vectorCross3D(xci, Fn_i, torque_i);
           }
       #endif
@@ -166,7 +166,7 @@ namespace ContactModels
         i_forces.delta_F[0] = Fn_ * sidata.en[0];
         i_forces.delta_F[1] = Fn_ * sidata.en[1];
         i_forces.delta_F[2] = Fn_ * sidata.en[2];
-        #ifdef SUPERQUADRIC_ACTIVE_FLAG
+        #ifdef NONSPHERICAL_ACTIVE_FLAG
                 if(sidata.is_non_spherical) {
                   //for non-spherical particles normal force can produce torque!
                   i_forces.delta_torque[0] += torque_i[0];
@@ -182,12 +182,12 @@ namespace ContactModels
         j_forces.delta_F[0] = -i_forces.delta_F[0];
         j_forces.delta_F[1] = -i_forces.delta_F[1];
         j_forces.delta_F[2] = -i_forces.delta_F[2];
-        #ifdef SUPERQUADRIC_ACTIVE_FLAG
+        #ifdef NONSPHERICAL_ACTIVE_FLAG
                 if(sidata.is_non_spherical) {
                   //for non-spherical particles normal force can produce torque!
                   double xcj[3], torque_j[3];
                   double Fn_j[3] = { -Fn_i[0], -Fn_i[1], -Fn_i[2]};
-                  vectorSubtract3D(sidata.contact_point, sidata.pos_j, xcj);
+                  vectorSubtract3D(sidata.contact_point, atom->x[sidata.j], xcj);
                   vectorCross3D(xcj, Fn_j, torque_j);
 
                   i_forces.delta_torque[0] += torque_i[0];
