@@ -42,9 +42,9 @@
 #ifndef LMP_PROBABILITY_DISTRIBUTION_H
 #define LMP_PROBABILITY_DISTRIBUTION_H
 
-#include "math.h"
-#include "stdio.h"
-#include "string.h"
+#include <math.h>
+#include <stdio.h>
+#include <string.h>
 #include "random_park.h"
 #include "error.h"
 #include "pointers.h"
