@@ -84,6 +84,9 @@ class Region : protected Pointers {
 
   // called by other classes to check point versus region
 
+  inline int match(double *point) 
+  { return match(point[0],point[1],point[2]);}
+
   int match(double, double, double);
   int surface(double, double, double, double);
 
@@ -131,6 +134,7 @@ class Region : protected Pointers {
   class RanPark *random;
   
  private:
+  double volume_limit_;             //volume below which error will be thrown
   int dynamic;                      // 1 if region position/orientation changes over time
   int moveflag,rotateflag;          // 1 if position/orientation changes
   double point[3],axis[3],runit[3];
