@@ -42,7 +42,7 @@
 #ifndef LMP_VECTOR_LIGGGHTS_H
 #define LMP_VECTOR_LIGGGHTS_H
 
-#include "math.h"
+#include <math.h>
 #include "lammps.h"
 
 namespace LAMMPS_NS {
@@ -509,6 +509,14 @@ inline double vectorCrossMag3D(const double *v1,const double *v2)
   return vectorMag3D(res);
 }
 
+template<typename T>
+inline void vectorProject3D(const T *v, const T *on, T *result)
+{
+  T norm[3] = {on[0], on[1], on[2]};
+  vectorNormalize3D(norm);
+  vectorScalarMult3D(norm,vectorDot3D(v,norm),result);
+}
+
 inline void vectorZeroize3D(double *v)
 {
   v[0]=0.;
